
% ----------------------------------------------------------------------%
%   Programa para analizar la estabilidad de un sistema mecnico         
%   anlogo al comportamiento de la mquina sncrona                                              
%   obtencion del tiempo critico Tc, angulo critico Delta_c                  
%   y tiempo y angulo de inestabilidad: T_nest Ang_inest                    
%   M2 y M1 diferentes de cero, M0prima menor a M0                   
% -----------------------------------------------------------------------%

% -----------------------------------------------------------------------%
%     Tiempos de la corrida
% ------------------------------------------------------------------------------------------%
 clear all 
 tinter_i=0;                                                                      % tiempo de inicio del barrido
 tinter_f=1;                                                                      % tiempo final tentativo del barrido
 npuntos_barrido=200;                                                    % puntos del barrido
 delta_inter=(tinter_f-tinter_i)/npuntos_barrido;       % intervalo de incremento del barrido         
 ang_inest=pi;                                                                   % angulo maximo fijado por el usuario
 
 
 for tinter = tinter_i:delta_inter:tinter_f
         
 ti = 0;                                  % tiempo inicial de la simulacion
 tf = 12;                                 % tiempo final de la simulacion
 n_puntos = 4000;                % numero de puntos de la simulacion
 delta = (tf-ti)/n_puntos;    % paso de integracion para Runge-Kutta
% -----------------------------------------------------------------%
%     Valores numricos de los parmetros del sistema en el SI
%      durante el periodo de falla
% -----------------------------------------------------------------%

 M0  = 0;
 M1   = 0.1;
 M2  = 1;
 M3  = 0;
 g     = 9.81;                     
 r     = 0.1;                      
 mB  = 0.386; 
 mp  = 1.484;               
 lB   = 0.438;                    
  mu=0.14;
 mt=M0+M1+M2+M3+mB+mp;
 n=mu*mt*g;
 % -----------------------------------------------------------------%
%     Definicion de constantes del modelo
%      durante el periodo del corte de M0
% -----------------------------------------------------------------%

mprima=M2-M1;
M = (M0+M1+M2+M3);
I = M*r^2+(1/2)*mp*r^2+(1/12)*mB*lB^2; 
K = mB*g*lB/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
%    que dura el corte de M0
% -----------------------------------------------------------------%

 DTet_0 = 0;                % velocidad inicial en t=0
 Tet_0  = 0.5418;         % angulo de equilibrio en t=0      

% -----------------------------------------------------------------%

[t,x] = sim('Est_sist_mec_sim',[ti tinter]);
   z1 = x;
   t1 = t;
   
% -----------------------------------------------------------------%
%     Valores numricos renombrados de los parmetros del sistema
%      para el periodo de acoplo de M3
% -----------------------------------------------------------------%  

 M0  =0; 
 M1  =0.1;
 M2=1;
 M3=0.221;
 mp = 1.484;               
 g  = 9.81;                     
 r  = 0.1;                      
 mB = 0.386;                     
 lB = 0.438;                    
 mt=M0+M1+M2+M3+mB+mp;
 n=mu*mt*g;
 
 % -----------------------------------------------------------------%
%     Definicion de constantes del modelo
%     en el periodo de acoplo de M3
% -----------------------------------------------------------------%

mprima=M2-M3-M1;
M = M0+M3+M1+M2;
I = M*r^2+(1/2)*mp*r^2+(1/12)*mB*lB^2; 
K = mB*g*lB/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
%    en el momento del acoplo de M3
% -----------------------------------------------------------------%

DTet_0 = x(end,1);
Tet_0 = x(end,2);

% -----------------------------------------------------------------%

[t,x] = sim('Est_sist_mec_sim',[tinter tf]);

t2=t;
z2=x;
t=[t1;t2];
z=[z1;z2];


% -----------------------------------------------------------------%  
% Obtencion del valor del tiempo y la posicion inestables 
% -----------------------------------------------------------------%

 for k=1:length(z(:,2))
     if abs(z(k,2))>=ang_inest
         sal=[k,t(k),z(k,2)];
         graficas_subplot_t_x_t_v;
         pause
         clf;
         break
     end
 end
  %grafica_t_ang
%graficas_subplot_t_x_t_v;
graficas_plot_x_v;

end %  {fin del for inter}






