
% ----------------------------------------------------------------------%
%   Programa para analizar la estabilidad de un sistema mecnico         
%   anlogo al comportamiento de la mquina sncrona                          
%   Analisis para el caso 3 de una falla con recierre,                           
%   obtencion del tiempo critico Tc, angulo critico Delta_c                  
%   y tiempo y angulo de inestabilidad: T_nest Ang_inest                    
%   M2 y M1 diferentes de cero, M0prima menor a M0                   
% -----------------------------------------------------------------------%

% -----------------------------------------------------------------------%
%     Tiempos de la corrida
% -----------------------------------------------------------------------%
 clear all 
 ti = 0;                                  % tiempo inicial de la simulacion
 tf=10;                                  % tiempo final de la simulacion
 
 for tc = [0.18 0.21 0.23]                            % tiempo final de la simulacion tin=0.33
 n_puntos = 2000;                  % numero de puntos de la simulacion
 delta = (tf-ti)/n_puntos;    % paso de integracion para Runge-Kutta
 ang_inest=pi;

% -----------------------------------------------------------------%
%     Valores numricos de los parmetros del sistema en el SI
%      durante el periodo de falla
% -----------------------------------------------------------------%

 M0=0;
 M1  =0.1;
 M2=1;
 M3=0;
 g   = 9.81;                     
 r   =  0.1;                      
 mB  =  0.386; 
 mp  = 1.484;               
 lB  = 0.438;                    
 B   = 0.0;  
 
 
% -----------------------------------------------------------------%
%     Definicion de constantes del modelo
%      durante el periodo del corte de M0
% -----------------------------------------------------------------%

mprima=M2-M1;
M = (M0+M1+M2+M3);
I = M*r^2+(1/2)*mp*r^2+(1/12)*mB*lB^2; 
K = mB*g*lB/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
%    que dura el corte de M0
% -----------------------------------------------------------------%

 DTet_0 = 0;                % velocidad inicial en t=0
 Tet_0  = 0.5418;         % angulo de equilibrio en t=0      

% -----------------------------------------------------------------%

[t,x] = sim('Est_sist_mec_sim',[ti tc]);
   z1 = x;
   t1 = t;
   
% -----------------------------------------------------------------%
%     Valores numricos renombrados de los parmetros del sistema
%      para el periodo de acoplo de M3
% -----------------------------------------------------------------%  

 M0  =0; 
 M1  =0.1;
 M2=1;
 M3=0.221;
 mp = 1.484;               
 g  = 9.81;                     
 r  = 0.1;                      
 mB = 0.386;                     
 lB = 0.438;                    
 B  = 0.0; 
 
 % -----------------------------------------------------------------%
%     Definicion de constantes del modelo
%     en el periodo de acoplo de M3
% -----------------------------------------------------------------%

mprima=M2-M3-M1;
M = M0+M3+M1+M2;
I = M*r^2+(1/2)*mp*r^2+(1/12)*mB*lB^2; 
K = mB*g*lB/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
%    en el momento del acoplo de M3
% -----------------------------------------------------------------%

DTet_0 = x(end,1);
Tet_0 = x(end,2);

% -----------------------------------------------------------------%

[t,x] = sim('Est_sist_mec_sim',[tc tf]);

t2=t;
z2=x;
t=[t1;t2];
z=[z1;z2];


% -----------------------------------------------------------------%  
% Obtencion del valor del tiempo y la posicion inestables 
% -----------------------------------------------------------------%

 for k=1:length(z(:,2))
     if abs(z(k,2))>=ang_inest
         sal=[k,t(k),z(k,2)];
         break
      end
 end
 
 
%Grafica plano de fase
plot(z(:,2),z(:,1))
axis([0 pi,-4 4])
grid on
hold on

%Grafica de la velocidad o angulo contra el tiempo
% con la estabilidad
%plot(t,z(:,2))
%grid on
%pause

%Grafica de la velocidad o angulo contra el tiempo
% inestables
%plot(t,z(:,1))
%axis([0 2.5 0 20])  %para la velocidad
%axis([0 2.5 0 18])  %para el angulo
%grid on
%pause


end






