
% ----------------------------------------------------------------------%
%   Programa para analizar la estabilidad de un sistema mecnico         
%   anlogo al comportamiento de la mquina sncrona                          
%   Analisis para el caso de tres trayectorias                         
%   a) Estable antes del umbral                
%   b) Estable en el Umbral                 
%   c) Inestable despues del Umbral                  
% -----------------------------------------------------------------------%

% -----------------------------------------------------------------------%
%     Tiempos de la corrida
% -----------------------------------------------------------------------%
 clear all 
 clc
 
 ti = 0;                                  % tiempo inicial de la simulacion
 tf=10;                                  % tiempo final de la simulacion
 
 
 n_puntos = 2000;                  % numero de puntos de la simulacion
 delta = (tf-ti)/n_puntos;    % paso de integracion para Runge-Kutta
 
% -----------------------------------------------------------------%
%     Valores numricos de los parmetros del sistema en el SI
%      durante el periodo de falla
% -----------------------------------------------------------------%

 m0=0.4641;
 m1  =0.1;
 m2=1;
 m3=0.221;
 g   = 9.81;                     
 r   =  0.1;                      
 mB  =  0.386; 
 mp  = 1.484;               
 lB  = 0.438;                    
 B   = 0.04;  
 
 ang_inest=pi;

 for tc = [0.4,0.51]         % tiempos: antes, durante y despues del Umbral 

% -----------------------------------------------------------------%
%     Definicion de constantes del modelo
%      durante el periodo del corte de M0
% -----------------------------------------------------------------%
mprima = (m2-m1);
I = mp*r^2+(1/2)*mp*r^2+(1/12)*mB*lB^2; 
K = mB*g*lB/2;

% -----------------------------------------------------------------%

%    Condiciones iniciales durante el intervalo [0,tinter]
%    que dura el corte de M0

% -----------------------------------------------------------------%

 DTet_0 = 0;                % velocidad inicial en t=0
 Tet_0  = 0.5418;         % angulo de equilibrio en t=0   
 
% -----------------------------------------------------------------%

[t,x] = sim('Est_sist_mec_sim',[ti tc]);
   z1 = x;
   t1 = t;
   
% -----------------------------------------------------------------%
%     Definicion de constantes del modelo
%     en el periodo de acoplo de M3
% -----------------------------------------------------------------%
 
 
mprima=m2-m3-m1;
I = (m1+m2+m3)*r^2+(1/2)*mp*r^2+(1/12)*mB*lB^2; 
K = mB*g*lB/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
%    en el momento del acoplo de M3
% -----------------------------------------------------------------%

DTet_0 = x(end,1);
Tet_0 = x(end,2);

% -----------------------------------------------------------------%

[t,x] = sim('Est_sist_mec_sim',[tc tf]);

t2=t;
z2=x;
t=[t1;t2];
z=[z1;z2];


%Grafica plano de fase
plot(z(:,2),z(:,1))

axis([0,3,-2.5,3])
grid on
hold on



end






