% -----------------------------------------------------------------%
%   Programa para analizar la estabilidad de un sistema mecnico 
%   anlogo al comportamiento de la mquina sncrona
% -----------------------------------------------------------------%
%     Tiempos de la corrida
% -----------------------------------------------------------------%

 clear all 
 clc
 tinter_i=0;                                    % tiempo en el que se desconecta m2
 tinter_f=2;                                   % tiempo en el que se vuelve a conectar m2
 delta_inter=0.005;                       % intervalo de incremento
 ang_inest=4.4;                              % dos veces el angulo de equilbrio inestable
                                                       %  de posfalla, (2*2.208)
 for tinter = tinter_i:delta_inter:tinter_f
     
 ti = 0;                                      % tiempo inicial de la simulacion
 tf = 15;                                     % tiempo final de la simulacion
 n_puntos = 5000;                   % numero de puntos de la simulacion
 delta = (tf-ti)/n_puntos;        % paso de integracion para Runge-Kutta

% -----------------------------------------------------------------%
%     Valores numricos de los parmetros del sistema
% -----------------------------------------------------------------%
 Tm  = 49.8;              % Par externo aplicado a la polea [N.m]
 r  = 0.2;                    % radio de la polea [m]
 mp = 10;                   % masa de la polea [kg]
 mb = 22.7;                % masa de la barra [kg]
 lb = .2;                     % longitud de la barra[m]
 m1 = 8;                    % masa m1 [kg]
 m2 = 0;                    % masa m2 [kg]
 B  = 0.2;                      % coeficiente de amortiguacion 
                                  % rotacional [N.s/rad]

% -----------------------------------------------------------------%
%     Definicion de constantes del modelo
% -----------------------------------------------------------------%

 I = (m1+m2)*r^2+0.5*mp*r^2+(1/3)*mb*lb^2;  
 mprima=(m1-m2);
 m=m1+m2;
 g  = 10;              
 K=mb*g*lb/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
% -----------------------------------------------------------------%

 DTet_0=0;
 Tet_0 = 0.5418;          

% -----------------------------------------------------------------%
[t,x] = sim('c:\matlab6p5\work\Estabilidad del sistema mecanico 2\Est_sist_mec_sim',[ti tinter]);
z1=x;
t1 = t;
tc=t1(end);

% -----------------------------------------------------------------%
%     Valores numricos de los parmetros del sistema
% -----------------------------------------------------------------%

Tm  = 49.8;                     % Par externo aplicado a la polea [N.m]
r  = 0.2;                    % radio de la polea en [m]
mp = 10;                     % masa de la polea en [kg]
mb = 22.7;                      % masa de la barra [kg]
lb = .2;                      % longitud de la barra[m]
m1 = 8;                    % masa m1[kg]
m2 = 13.39;                    % masa m2[kg]
B  = 0.2;                   % coeficiente de amortiguacion 
                             % rotacional[N.s/rad]

% -----------------------------------------------------------------%
%     Definicion de constantes del modelo
% -----------------------------------------------------------------%

I = (m1+m2)*r^2+0.5*mp*r^2+(1/3)*mb*lb^2;   
m=m1+m2;
mprima=m1-m2;
g  = 10;              
K=mb*g*lb/2;

% -----------------------------------------------------------------%
%    Condiciones iniciales durante el intervalo [0,tinter]
% -----------------------------------------------------------------%

DTet_0 = x(end,1);
Tet_0 = x(end,2);

% -----------------------------------------------------------------%

[t,x] = sim('c:\matlab6p5\work\Estabilidad del sistema mecanico 2\Est_sist_mec_sim',[tinter tf]);

t2=t;
z2=x;
tout=[t1;t2];
z=[z1;z2];

% -----------------------------------------------------------------%  
% Obtencion del valor del tiempo y la posicion critica para 
% cuando el sistema gira dos vueltas y comienza a ser inestable
% -----------------------------------------------------------------%

 for k=1:length(z(:,2))
     if abs(z(k,2))>ang_inest
        save nn tout z
        load nn;
        sal=[k,tout(k),z(k,2)];
        break
      end
  end
 
%graficas_subplot_t_x_t_v;
graficas_plot_x_v;

end %  {fin del for inter}






